==> opengnsys-0.9.2-r1301.tar.gz: opengnsys/admin/WebConsole/gestores/gestor_administradores_usuarios.php <==
<?
// *************************************************************************************************************************************************
// Aplicación WEB: ogAdmWebCon
// Autor: José Manuel Alonso (E.T.S.I.I.) Universidad de Sevilla
// Fecha Creación: Año 2003-2004
// Fecha Última modificación: Marzo-2005
// Nombre del fichero: gestor_dministradores_centros.php
// Descripción :
//		Gestiona la asignación de administradores a las Unidades organizativas
// *************************************************************************************************************************************************
include_once("../includes/ctrlacc.php");
include_once("../clases/AdoPhp.php");
include_once("../includes/CreaComando.php");
include_once("../includes/opciones.php");
//________________________________________________________________________________________________________
$opcion=0; // Inicializa parametros
$idcentro=0; 
$idusuario=0; 

if (isset($_GET["opcion"])) $opcion=$_GET["opcion"]; // Recoge parametros

if (isset($_GET["idusuario"])) $idusuario=$_GET["idusuario"];
if (isset($_GET["idcentro"])) $idcentro=$_GET["idcentro"];

$cmd=CreaComando($cadenaconexion); // Crea objeto comando
$resul=false;
if ($cmd){
	$resul=Gestiona();
	$cmd->Conexion->Cerrar();
}
?>
<HTML>
<HEAD>
	<meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
<BODY>
<?
$literal="";
switch($opcion){
	case $op_alta :
		$literal="resultado_insertar_centros_administradores";
		break;
	case $op_eliminacion :
		$literal="resultado_eliminar_centros_administradores";
		break;
	default:
		break;
}
if ($resul){
	echo '<SCRIPT language="javascript">'.chr(13);
	if ($opcion==$op_alta )
		echo 'window.parent.'.$literal."(1,'".$cmd->DescripUltimoError()." ',".$idcentro.");".chr(13);
	else
		echo 'window.parent.'.$literal."(1,'".$cmd->DescripUltimoError()." ',".$idcentro.");".chr(13);
	echo '</SCRIPT>';
}
else{
	echo '<SCRIPT language="javascript">';
	echo "	window.parent.".$literal."(0,'".$cmd->DescripUltimoError()."',".$idcentro.")";
	echo '</SCRIPT>';
}
?>
</BODY>
</HTML>	
<?
// *************************************************************************************************************************************************
function Gestiona(){
	global	$cmd;
	global	$opcion;
	global	$idusuario;
	global	$idcentro;
	global  $urlimgth;
	global	$op_alta;
	global	$op_eliminacion;


	$cmd->CreaParametro("@idcentro",$idcentro,1);
	$cmd->CreaParametro("@idusuario",$idusuario,1);


	switch($opcion){
		case $op_alta :
			$cmd->texto="INSERT INTO administradores_centros(idusuario,idcentro) VALUES (@idusuario,@idcentro)";
			$resul=$cmd->Ejecutar();
			break;
		case $op_eliminacion :
			$cmd->texto='DELETE  FROM administradores_centros WHERE idusuario='.$idusuario.' AND idcentro='.$idcentro;
			$resul=$cmd->Ejecutar();
			break;
		default:
			break;
	}
	return($resul);
}
?>

==> opengnsys-1.1.0-r5652.tar.gz: opengnsys/admin/WebConsole/gestores/gestor_administradores_usuarios.php <==
<?php
// *************************************************************************************************************************************************
// Aplicación WEB: ogAdmWebCon
// Autor: José Manuel Alonso (E.T.S.I.I.) Universidad de Sevilla
// Fecha Creación: Año 2009-2010
// Fecha Última modificación: Agosto-2010
// Nombre del fichero: gestor_dministradores_centros.php
// Descripción :
//		Gestiona la asignación de administradores a las Unidades organizativas
// *************************************************************************************************************************************************
include_once("../includes/ctrlacc.php");
include_once("../clases/AdoPhp.php");
include_once("../includes/CreaComando.php");
include_once("../includes/opciones.php");
//________________________________________________________________________________________________________
$opcion=0; // Inicializa parametros
$idcentro=0; 
$idusuario=0; 

if (isset($_POST["opcion"])) $opcion=$_POST["opcion"]; // Recoge parametros

if (isset($_POST["idusuario"])) $idusuario=$_POST["idusuario"];
if (isset($_POST["idcentro"])) $idcentro=$_POST["idcentro"];

$cmd=CreaComando($cadenaconexion); // Crea objeto comando
$resul=false;
if ($cmd){
	$resul=Gestiona();
	$cmd->Conexion->Cerrar();
}
$literal="";
switch($opcion){
	case $op_alta :
		$literal="resultado_insertar_centros_administradores";
		break;
	case $op_eliminacion :
		$literal="resultado_eliminar_centros_administradores";
		break;
	default:
		break;
}
if ($resul){
	if ($opcion==$op_alta )
		echo $literal."(1,'".$cmd->DescripUltimoError()." ',".$idcentro.");".chr(13);
	else
		echo $literal."(1,'".$cmd->DescripUltimoError()." ',".$idcentro.");".chr(13);
}
else{
	echo "	window.parent.".$literal."(0,'".$cmd->DescripUltimoError()."',".$idcentro.")";
}
// *************************************************************************************************************************************************
function Gestiona(){
	global	$cmd;
	global	$opcion;
	global	$idusuario;
	global	$idcentro;
	global  $urlimgth;
	global	$op_alta;
	global	$op_eliminacion;


	$cmd->CreaParametro("@idcentro",$idcentro,1);
	$cmd->CreaParametro("@idusuario",$idusuario,1);


	switch($opcion){
		case $op_alta :
			$cmd->texto="INSERT INTO administradores_centros(idusuario,idcentro) VALUES (@idusuario,@idcentro)";
			$resul=$cmd->Ejecutar();
			break;
		case $op_eliminacion :
			$cmd->texto='DELETE  FROM administradores_centros WHERE idusuario='.$idusuario.' AND idcentro='.$idcentro;
			$resul=$cmd->Ejecutar();
			break;
		default:
			break;
	}
	return($resul);
}
?>
